==> freemedforms-project_0.7.1.orig.tar.gz: freemedforms-0.7.1/global_resources/translations/xmlioplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>XmlForms::Internal::XmlFormIO</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="141"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="209"/>
        <source>Invalid file detected.</source>
        <translation>Fichier invalide détecté.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="142"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="210"/>
        <source>An invalid file was found. Please contact your software administrator.
Wrong file: %1
Error: %2</source>
        <translation>Un fichier invalide a été trouvé. Veuillez contacter votre administrateur logiciel.
Fichier : %1
Erreur : %2</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="325"/>
        <source>No form file name</source>
        <translation>Pas de nom de formulaire</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="535"/>
        <source>Form: </source>
        <translation>Formulaire : </translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="536"/>
        <source>Database version: %1</source>
        <translation>Version en base de données : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="548"/>
        <source>Form update detected.</source>
        <translation>Mise à jour de formulaire détectée.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="549"/>
        <source>A form update has been detected. Do you want to update the forms?</source>
        <translation>Une mise à jour de formulaire a été détectée. Voulez-vous mettre à jour les formulaires ?</translation>
    </message>
</context>
<context>
    <name>XmlIOBase</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmliobase.cpp" line="191"/>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.7.4.orig.tar.gz: freemedforms-0.7.4/global_resources/translations/xmlioplugin_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>XmlForms::Internal::XmlFormIO</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="141"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="209"/>
        <source>Invalid file detected.</source>
        <translation>Fichier invalide détecté.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="142"/>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="210"/>
        <source>An invalid file was found. Please contact your software administrator.
Wrong file: %1
Error: %2</source>
        <translation>Un fichier invalide a été trouvé. Veuillez contacter votre administrateur logiciel.
Fichier : %1
Erreur : %2</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="325"/>
        <source>No form file name</source>
        <translation>Pas de nom de formulaire</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="468"/>
        <source>Form: </source>
        <translation>Formulaire : </translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="469"/>
        <source>New version: %1</source>
        <translation>Nouvelle version : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="470"/>
        <source>Database version: %1</source>
        <translation>Version en base de données : %1</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="484"/>
        <source>Form update detected.</source>
        <translation>Mise à jour de formulaire détectée.</translation>
    </message>
    <message>
        <location filename="../../plugins/xmlioplugin/xmlformio.cpp" line="485"/>
        <source>A form update has been detected. Do you want to update the forms?</source>
        <translation>Une mise à jour de formulaire a été détectée. Voulez-vous mettre à jour les formulaires ?</translation>
    </message>
</context>
<context>
    <name>XmlForms::Internal::XmlIOBase</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmliobase.cpp" line="649"/>
        <source>Error while saving PMHxCateogries (%1)</source>
        <translation>Erreur lors de la sauvegarde des catégories ATCD (%1)</translation>
    </message>
</context>
<context>
    <name>XmlIOBase</name>
    <message>
        <location filename="../../plugins/xmlioplugin/xmliobase.cpp" line="198"/>
        <source>Trying to create empty database.
       Location: %1
       FileName: %2
       Driver: %3</source>
        <translation></translation>
    </message>
</context>
</TS>
